
<!-- network application_security_groups -->
<script id="services.network.application_security_groups.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">Name: <span id="network.application_security_groups.{{@key}}.name"><samp>{{value_or_none name}}</samp></span></div>
        <div class="list-group-item-text item-margin">Location: <span id="network.application_security_groups.{{@key}}.location"><samp>{{value_or_none location}}</samp></span></div>
        <div class="list-group-item-text item-margin">Provisioning State: <span id="network.application_security_groups.{{@key}}.provisioning_state"><samp>{{value_or_none provisioning_state}}</samp></span></div>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Attached Network Interfaces</h4>
        {{#each network_interfaces}}
        <div class="list-group-item-text item-margin"><a href="javascript:showObject('services.network.network_interfaces.{{this}}')"><samp>{{getValueAt 'services.network.network_interfaces' this 'name'}}</samp></a></div>
        {{else}}
        <div class="list-group-item-text item-margin"><samp>None</samp></div>
        {{/each}}
    </div>
</script>

<script>
    Handlebars.registerPartial("services.network.application_security_groups", $("#services\\.network\\.application_security_groups\\.partial").html());
</script>

<!-- Single network application_security_group template -->
<script id="single_network_application_security_group-template" type="text/x-handlebars-template">
    {{> modal-template template='services.network.application_security_groups'}}
</script>
<script>
    var single_network_application_security_group_template = Handlebars.compile($("#single_network_application_security_group-template").html());
</script>
