
<!-- graphrbac applications -->
<script id="services.graphrbac.applications.partial" type="text/x-handlebars-template">
    <div id="resource-name" class="list-group-item active">
        <h4 class="list-group-item-heading">{{name}}</h4>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Information</h4>
        <div class="list-group-item-text item-margin">ID: <span id="graphrbac.applications.{{@key}}.id"><samp>{{value_or_none id}}</samp></span></div>
        <div class="list-group-item-text item-margin">App ID: <span id="graphrbac.applications.{{@key}}.app_id"><samp>{{value_or_none app_id}}</samp></span></div>
        <div class="list-group-item-text item-margin">Type: <span id="graphrbac.applications.{{@key}}.object_type"><samp>{{value_or_none object_type}}</samp></span></div>
        <div class="list-group-item-text item-margin">Sign In Audience: <span id="graphrbac.applications.{{@key}}.sign_in_audience"><samp>{{value_or_none sign_in_audience}}</samp></span></div>
        <div class="list-group-item-text item-margin">Publisher Domain: <span id="graphrbac.applications.{{@key}}.publisher_domain"><samp>{{value_or_none publisher_domain}}</samp></span></div>
        <div class="list-group-item-text item-margin">Available To Other Tenants: <span id="graphrbac.applications.{{@key}}.available_to_other_tenants"><samp>{{value_or_none available_to_other_tenants}}</samp></span></div>
        <div class="list-group-item-text item-margin">Allow Guests Sign-In: <span id="graphrbac.applications.{{@key}}.allow_guests_sign_in"><samp>{{value_or_none allow_guests_sign_in}}</samp></span></div>
        <div class="list-group-item-text item-margin">Allow Passthrough Users: <span id="graphrbac.applications.{{@key}}.allow_passthrough_users"><samp>{{value_or_none allow_passthrough_users}}</samp></span></div>
        <div class="list-group-item-text item-margin">Public Client: <span id="graphrbac.applications.{{@key}}.public_client"><samp>{{value_or_none public_client}}</samp></span></div>
        <div class="list-group-item-text item-margin">Device-Only Auth Supported: <span id="graphrbac.applications.{{@key}}.is_device_only_auth_supported"><samp>{{value_or_none is_device_only_auth_supported}}</samp></span></div>
        <div class="list-group-item-text item-margin">Pre-Authorized Applications: <span id="graphrbac.applications.{{@key}}.pre_authorized_applications"><samp>{{value_or_none pre_authorized_applications}}</samp></span></div>
        <div class="list-group-item-text item-margin">Deletion Timestamp: <span id="graphrbac.applications.{{@key}}.deletion_timestamp"><samp>{{value_or_none deletion_timestamp}}</samp></span></div>
    </div>
    <div class="list-group-item">
        <h4 class="list-group-item-heading">Password Credentials
            {{> count_badge count=password_credentials.length}}
        </h4>
        <div class="accordion-inner">
            <ul>
                {{#each password_credentials}}
                <li class="list-group-item-text">ID: <samp>{{value_or_none this.key_id}}</samp></li>
                <ul>
                    <li class="list-group-item-text">Start Date: {{format_date this.start_date}}</li>
                    <li class="list-group-item-text">End Date: {{format_date this.end_date}}</li>
                </ul>
                {{/each}}
            </ul>
        </div>
    </div>
</script>

<script>
    Handlebars.registerPartial("services.graphrbac.applications", $("#services\\.graphrbac\\.applications\\.partial").html());
</script>

<!-- Single graphrbac application template -->
<script id="single_graphrbac_application-template" type="text/x-handlebars-template">
    {{> modal-template template='services.graphrbac.applications'}}
</script>
<script>
    var single_graphrbac_application_template = Handlebars.compile($("#single_graphrbac_application-template").html());
</script>
